c         this list block data names as external names so that the
c       block data is surely enabled.
      external cblkElemag
      external cblkdedx
      external cblkHeavy 
      external cblkManager 
c      external cblkStdAtmos
      external cblkXsec
      external cblkEvhnp
      external cblkIncident
      external cblkObs
      external cblkTracking
      external cblkMuInt
c              For Lund related block common
      external blkhd1, blkhd2, blkhd3, blkhd4
      external blkdc1, blkdc2
      external ludataC
      external luedatC
      external luhdatC
